@@ -44,6 +44,11 @@ sub backend_block_keywords {
           label   => 'Generate Root Path',
           descr   => q!Adds a root => 'html' statement to config!,
           type    => 'boolean' },
+
+        { keyword => 'template',
+          label   => 'Alternate Template',
+          descr   => 'A custom TT template.',
+          type    => 'text' },
     ];
 }
 
@@ -187,7 +192,7 @@ sub setup_template {
 }
 
 # application
-package #
+package # application
     application;
 use strict; use warnings;
 
@@ -276,8 +281,7 @@ sub output_httpd_conf_locations {
     return [ $output ];
 }
 
-# app_statement
-package #
+package # app_statement
     app_statement;
 use strict; use warnings;
 
@@ -292,7 +296,7 @@ sub output_httpd_conf_loc {
 }
 
 # app_config_block
-package #
+package # app_config_block
     app_config_block;
 use strict; use warnings;
 
@@ -308,8 +312,8 @@ sub output_configs {
     foreach my $config ( @{ $child_output } ) {
         $output .= Bigtop::Backend::HttpdConf::Gantry::config(
             {
-                var   => $config->{__NAME__},
-                value => $config->{__VALUE__},
+                var   => $config->{__KEYWORD__},
+                value => $config->{__ARGS__},
             }
         );
     }
@@ -326,8 +330,7 @@ sub output_configs {
     return [ $output ];
 }
 
-# app_config_statement
-package #
+package # app_config_statement
     app_config_statement;
 use strict; use warnings;
 
@@ -336,11 +339,13 @@ sub output_configs {
 
     my $output_vals = $self->{__ARGS__}->get_args();
 
-    return [ { __NAME__ => $self->{__KEY__}, __VALUE__ => $output_vals } ];
+    return [ {
+            __KEYWORD__ => $self->{__KEYWORD__},
+            __ARGS__    => $output_vals
+    } ];
 }
 
-# literal_block
-package #
+package # literal_block
     literal_block;
 use strict; use warnings;
 
@@ -367,7 +372,7 @@ sub output_httpd_conf_locations {
 }
 
 # controller_block
-package #
+package # controller_block
     controller_block;
 use strict; use warnings;
 
@@ -424,7 +429,7 @@ sub output_httpd_conf_locations {
 }
 
 # controller_statement
-package #
+package # controller_statement
     controller_statement;
 use strict; use warnings;
 
@@ -443,7 +448,7 @@ sub output_httpd_conf_locations {
 }
 
 # controller_config_block
-package #
+package # controller_config_block
     controller_config_block;
 use strict; use warnings;
 
@@ -460,8 +465,8 @@ sub output_controller_configs {
     foreach my $config ( @{ $child_output } ) {
         $output .= Bigtop::Backend::HttpdConf::Gantry::config(
             {
-                var   => $config->{__NAME__},
-                value => $config->{__VALUE__},
+                var   => $config->{__KEYWORD__},
+                value => $config->{__ARGS__},
             }
         );
     }
@@ -469,8 +474,7 @@ sub output_controller_configs {
     return [ $output ];
 }
 
-# controller_config_statement
-package #
+package # controller_config_statement
     controller_config_statement;
 use strict; use warnings;
 
@@ -479,11 +483,14 @@ sub output_controller_configs {
 
     my $output_vals = $self->{__ARGS__}->get_args();
 
-    return [ { __NAME__ => $self->{__KEY__}, __VALUE__ => $output_vals } ];
+    return [ {
+            __KEYWORD__ => $self->{__KEYWORD__},
+            __ARGS__    => $output_vals
+    } ];
 }
 
 # controller_literal_block
-package #
+package # controller_literal_block
     controller_literal_block;
 use strict; use warnings;
 
@@ -542,6 +549,43 @@ This module does not register any keywords.  See Bigtop::HttpdConf
 for a list of allowed keywords (think app and controller level 'location'
 and controller level 'rel_location' statements).
 
+=head1 METHODS
+
+To keep podcoverage tests happy.
+
+=over 4
+
+=item backend_block_keywords
+
+Tells tentmaker that I understand these config section backend block keywords:
+
+    no_gen
+    instance
+    conffile
+    gen_root
+    full_use
+    skip_config
+    template
+
+=item what_do_you_make
+    
+Tells tentmaker what this module makes.  Summary: docs/httpd.conf.
+
+=item gen_HttpdConf
+
+Called by Bigtop::Parser to get me to do my thing.
+
+=item output_httpd_conf
+
+What I call on the AST packages to do my thing.
+
+=item setup_template
+
+Called by Bigtop::Parser so the user can substitute an alternate template
+for the hard coded one here.
+
+=back
+
 =head1 AUTHOR
 
 Phil Crow <philcrow2000@yahoo.com>
